@@ -166,6 +166,62 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateDDoSBlackWhiteIpList(self, request):
+        """添加DDoS防护的IP网段黑白名单
+
+        :param request: Request instance for CreateDDoSBlackWhiteIpList.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.CreateDDoSBlackWhiteIpListRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.CreateDDoSBlackWhiteIpListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateDDoSBlackWhiteIpList", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateDDoSBlackWhiteIpListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreateDDoSConnectLimit(self, request):
+        """配置DDoS连接抑制选项
+
+        :param request: Request instance for CreateDDoSConnectLimit.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.CreateDDoSConnectLimitRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.CreateDDoSConnectLimitResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateDDoSConnectLimit", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateDDoSConnectLimitResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateDDoSGeoIPBlockConfig(self, request):
         """添加DDoS防护的区域封禁配置
 
@@ -334,6 +390,62 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreatePortAclConfig(self, request):
+        """添加DDoS防护的端口acl策略
+
+        :param request: Request instance for CreatePortAclConfig.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.CreatePortAclConfigRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.CreatePortAclConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreatePortAclConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePortAclConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def CreatePortAclConfigList(self, request):
+        """批量添加DDoS防护的端口acl策略
+
+        :param request: Request instance for CreatePortAclConfigList.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.CreatePortAclConfigListRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.CreatePortAclConfigListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreatePortAclConfigList", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePortAclConfigListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateProtocolBlockConfig(self, request):
         """设置DDoS防护的协议封禁配置
 
@@ -474,6 +586,34 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteDDoSBlackWhiteIpList(self, request):
+        """删除DDoS防护的IP网段黑白名单
+
+        :param request: Request instance for DeleteDDoSBlackWhiteIpList.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.DeleteDDoSBlackWhiteIpListRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DeleteDDoSBlackWhiteIpListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeleteDDoSBlackWhiteIpList", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteDDoSBlackWhiteIpListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteDDoSGeoIPBlockConfig(self, request):
         """删除DDoS防护的区域封禁配置
 
@@ -699,7 +839,7 @@ class AntiddosClient(AbstractClient):
 
 
     def DescribeCCTrend(self, request):
-        """获取CC攻击指标数据，包括总请求峰值(QPS)和攻击请求(QPS)
+        """获取CC攻击指标数据，包括总请求峰值(QPS)和攻击请求(QPS)以及总请求次数和攻击请求次数
 
         :param request: Request instance for DescribeCCTrend.
         :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeCCTrendRequest`
@@ -726,6 +866,34 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeDDoSBlackWhiteIpList(self, request):
+        """获取DDoS防护的IP网段黑白名单
+
+        :param request: Request instance for DescribeDDoSBlackWhiteIpList.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeDDoSBlackWhiteIpListRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DescribeDDoSBlackWhiteIpListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeDDoSBlackWhiteIpList", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeDDoSBlackWhiteIpListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeDDoSTrend(self, request):
         """获取DDoS攻击流量带宽和攻击包速率数据
 
@@ -1314,6 +1482,34 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyNewDomainRules(self, request):
+        """修改7层转发规则
+
+        :param request: Request instance for ModifyNewDomainRules.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.ModifyNewDomainRulesRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.ModifyNewDomainRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyNewDomainRules", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyNewDomainRulesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ModifyPacketFilterConfig(self, request):
         """修改DDoS防护的特征过滤规则
 
